# myUplink

Package for getting data from the myUplink API.

Primary usage is for [Home Assistant](https://www.home-assistant.io/integrations/myuplink/)

## Supported features
- Invoke ping and protected ping
- Get systems
- Get notifications
- Get devices on a system
- Get data points on a device

## Requirements
- aiohttp

## Test before commit
```
pip install .
python examples/example1.py
```
